@@ -11,9 +11,7 @@ void Generator::preIncludes(std::ostream &out) const
     key(out);
 
     if (polymorphic)
-        out << "#include <memory>\n"
-               "#include <stdexcept>\n"
-               "#include <type_traits>\n";
+        out << "#include <memory>\n";
  
     if (preInclude)    
         out << "#include " << d_options.preInclude() << '\n';
