@@ -4,15 +4,9 @@ void Generator::tokens(ostream &out) const
 {
     Terminal::ConstVector tokens;
 
-    for_each
-    (
-        d_rules.terminals().begin(), d_rules.terminals().end(), 
-        [&](Terminal const *terminal)
-        {
-            selectSymbolic(terminal, tokens);
-        }
-    );
- 
+    for (auto terminal: d_rules.terminals())
+        selectSymbolic(terminal, tokens);
+
     key(out);
  
     if (!tokens.size())
@@ -29,8 +23,3 @@ void Generator::tokens(ostream &out) const
 
 
 
-
-
-
-
-
