@@ -3,12 +3,8 @@
 void Options::setAccessorVariables()
 {
     setBooleans();
-
-                    // true if --target-directory was specified
-    bool targetDirOption = setBasicStrings();
-
-    setPathStrings(targetDirOption);
-
+    setBasicStrings();
+    setPathStrings();
     setQuotedStrings();
     setSkeletons();
 }
