@@ -7,10 +7,7 @@ void Parser::cleanup()
     if (!d_rules.hasRules() || !d_rules.nProductions())
         fmsg << "No production rules" << endl;
 
-    emsg.noLineNr();
-    emsg.setLineTag("");
-    wmsg.noLineNr();
-    wmsg.setLineTag("");
+    emsg.setTag("error");
 
     if (emsg.count())       // Terminate if parsing produced errors. 
         throw 1;
