@@ -13,7 +13,12 @@ char Parser::s_semanticValueStack[] = "d_vsp__";
 char Parser::s_locationValueStack[] = "d_lsp__";  
                                     // name of the location value stack
                                     // used by the generated parser
+char Parser::s_locationValue[] = "d_loc__";  
+                                    // name of the location value variable
+                                    // used by the generated parser (@0)
 
+char const Parser::s_stype__[] = "STYPE__";
+                                    // generic semantic value for POLYMORPHIC
 
 
 
