@@ -1,6 +1,6 @@
 #include "rules.ih"
 
-void Rules::addProduction()
+void Rules::addProduction(size_t lineNr)
 {
     if (d_currentRule == 0)                             // there may be no 
         return;                                         // rule (cf. Justin
@@ -9,7 +9,10 @@ void Rules::addProduction()
                                                         // that case there's
                                                         // also no production.
 
-    d_currentProduction = new Production(d_currentRule);// create production
+    s_lastLineNr = lineNr;
+
+                                                        // create production
+    d_currentProduction = new Production(d_currentRule, lineNr);
 
     d_production.push_back(d_currentProduction);        // put production in
                                                         // production  vector
@@ -17,9 +20,6 @@ void Rules::addProduction()
     d_currentRule->addProduction(d_currentProduction);  // add production to 
                                                         // current rule.
 
-// If this line is to be shown (it isn't in bisonc++ 2.8.0) then pass the
-// linenr from parser/openrule.cc, parser/parse.cc and rules/augmentgrammar.cc
-//
 //  imsg.setLineNr(lineNr);
 //  imsg << "  Adding production rule " << 
 //              d_currentRule->nProductions() << 
@@ -27,4 +27,3 @@ void Rules::addProduction()
 //              endl;
 }
 
-
