@@ -2,14 +2,14 @@
 
 void Rules::showUnusedNonTerminals() const
 {
-    wmsg.setTag("Warning");
+    Global::plainWarnings();
+
     for_each(d_nonTerminal.begin(), d_nonTerminal.end(), 
                                     &NonTerminal::unused);
 
     if (NonTerminal::notUsed())
         imsg << endl;
 
-    wmsg.setTag("Warning");
     for_each(d_nonTerminal.begin(), d_nonTerminal.end(), 
                                     &NonTerminal::undefined);
 
