@@ -7,11 +7,6 @@
 
 void Rules::updatePrecedences()
 {   
-    for_each(
-        d_production.begin(), d_production.end(),
-        [&](Production *production)
-        {
-            updatePrecedence(production, d_terminal);
-        }
-    );
+    for (auto production: d_production)
+        updatePrecedence(production, d_terminal);
 }
