@@ -4,13 +4,8 @@ void Writer::reduction(Table &table, StateItem const &stateItem)
 {
     size_t ruleNr = stateItem.nr();
 
-    for_each(
-        stateItem.lookaheadSet().begin(), stateItem.lookaheadSet().end(),
-        [&, ruleNr](Element const *sym)
-        {
-            reductionSymbol(sym, ruleNr, table);
-        }
-    );
+    for (auto sym: stateItem.lookaheadSet())
+        reductionSymbol(sym, ruleNr, table);
 
     if (stateItem.lookaheadSet().hasEOF())
         reductionSymbol(Rules::eofTerminal(), ruleNr, table);
